@@ -1,11 +1,11 @@
 SS.solve.SMW <-
 function (Z, F, H, Q, inv.R, length.out, P0, beta0 = 0) {
-	R <- inv.R
+    R <- inv.R
     rm(inv.R)
     d <- ncol(H)
     n <- nrow(H)
     T <- length.out
-    params <- .internal.chk.mod.params(F, H, Q, R, P0 = P0, beta0 = beta0, d, n) ### R IS INVERSE !!!
+    params <- internal.chk.mod.params(F, H, Q, R, P0 = P0, beta0 = beta0, d, n) ### R IS INVERSE !!!
     F <- params$F
     H <- params$H
     Q <- params$Q
@@ -28,9 +28,9 @@ function (Z, F, H, Q, inv.R, length.out, P0, beta0 = 0) {
         }
         P <- F %*% tcrossprod(P, F) + Q
         PtH <- tcrossprod(P, H)
-		
-		SMW.HPHR <- R - RH %*% solve( solve( P, tol=0 ) + tHRH,  tol=0 ) %*% tHR ###### R IS INVERSE !!!
-		
+        
+        SMW.HPHR <- R - RH %*% solve( solve( P, tol=0 ) + tHRH,  tol=0 ) %*% tHR ###### R IS INVERSE !!!
+        
         K <- PtH %*% SMW.HPHR
         B.apos[j, ] <- B.apri[j, ] + K %*% (Z[j, ] - H %*% B.apri[j, ])
         P <- (I - K %*% H) %*% P
